@@ -11,11 +11,11 @@ class BertEmbedding(TransformerEmbedding):
 
     def to_dict(self) -> Dict[str, Any]:
         info_dic = super(BertEmbedding, self).to_dict()
-        info_dic['config']['model_folder'] = self.model_folder
         return info_dic
 
     def __init__(self,
-                 model_folder: str,
+                 model_folder: str = None,
+                 model_type='bert',
                  **kwargs: Any):
         """
 
@@ -23,14 +23,16 @@ class BertEmbedding(TransformerEmbedding):
             model_folder: path of checkpoint folder.
             kwargs: additional params
         """
-        self.model_folder = model_folder
-        vocab_path = os.path.join(self.model_folder, 'vocab.txt')
-        config_path = os.path.join(self.model_folder, 'bert_config.json')
-        checkpoint_path = os.path.join(self.model_folder, 'bert_model.ckpt')
-        kwargs['vocab_path'] = vocab_path
-        kwargs['config_path'] = config_path
-        kwargs['checkpoint_path'] = checkpoint_path
-        kwargs['model_type'] = 'bert'
+        if model_folder:
+            if model_type == 'electra':
+                config_path = os.path.join(model_folder, 'bert_config.json')
+                checkpoint_path = os.path.join(model_folder, 'electra_base')
+            else:
+                config_path = os.path.join(model_folder, 'bert_config.json')
+                checkpoint_path = os.path.join(model_folder, 'bert_model.ckpt')
+            kwargs['checkpoint_path'] = checkpoint_path
+            kwargs['config_path'] = config_path
+        kwargs['model_type'] = model_type
         super(BertEmbedding, self).__init__(**kwargs)
 
 
